@@ -2,14 +2,16 @@ import os
 os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 if "PYUNITY_DEBUG_MODE" not in os.environ: os.environ["PYUNITY_DEBUG_MODE"] = "1"
 
-from .window import *
-
-windowProvider = None
 size = (800, 500)
 fps = 60
 faceCulling = True
 
-windowProviders = {"glut": glutWindow, "glfw": glfwWindow, "pygame": pygameWindow}
-
 if os.environ["PYUNITY_DEBUG_MODE"] == "1":
-    print("Loaded config")
\ No newline at end of file
+    print("Loaded config")
+
+from . import window
+
+windowProvider = window.LoadWindowProvider()
+
+del window
+del os
\ No newline at end of file
