@@ -4,17 +4,36 @@ from ..errors import *
 from .. import config
 
 class Window:
+    """
+    A window provider that uses GLFW.
+
+    Raises
+    ------
+    pyunityException
+        If the window creation fails
+    
+    """
+
     def __init__(self, size, name):
         glfw.init()
 
         self.window = glfw.create_window(*size, name, None, None)
         if not self.window:
             glfw.terminate()
-            raise PyUnityException("Cannot open GLFW window")
+            raise pyunityException("Cannot open GLFW window")
         
         glfw.make_context_current(self.window)
     
     def start(self, updateFunc):
+        """
+        Start the main loop of the window.
+
+        Parameters
+        ----------
+        updateFunc : function
+            The function that calls the OpenGL calls.
+        
+        """
         last = glfw.get_time()
         while not glfw.window_should_close(self.window):
             updateFunc()
